@@ -2,7 +2,7 @@ from functools import wraps
 from typing import Callable
 
 from django.http import HttpRequest, HttpResponse, HttpResponseForbidden, HttpResponseNotFound
-from nidhoggr_core.response import StatusResponse
+from nidhoggr.core.response import StatusResponse
 from pydantic import ValidationError
 from pydantic.main import BaseModel
 
