@@ -1,4 +1,3 @@
-from functools import partial
 from uuid import uuid4
 
 from django.contrib.auth.models import AbstractUser
@@ -7,7 +6,7 @@ from django.db import models
 from django.dispatch import receiver
 from django.utils.timezone import now
 
-from lavender import texture
+from lavender.utils import texture_path_handler
 
 
 class Player(AbstractUser):
@@ -71,29 +70,29 @@ class Quenta(models.Model):
         return f"{self.__class__.__name__} for {self.player.username}: {status}"
 
 
-class Wardrobe(models.Model):
-    player: Player = models.ForeignKey(Player, on_delete=models.CASCADE)
+class Texture(models.Model):
+    token: Token = models.ForeignKey(Token, on_delete=models.CASCADE)  # To avoid redundant joins
+    created = models.DateTimeField(default=now)
+    kind = models.CharField(max_length=6)
+    deleted = models.BooleanField(default=False)
 
-    skin_height = models.PositiveIntegerField(null=True)
-    skin_width = models.PositiveIntegerField(null=True)
-    skin = models.ImageField(null=True, blank=True, height_field='skin_height', width_field='skin_width',
-                             upload_to=partial(texture.path_handler, texture.TextureType.SKIN),
-                             storage=texture.OverwriteStorage())
+    height = models.PositiveIntegerField(null=True)
+    width = models.PositiveIntegerField(null=True)
+    image = models.ImageField(
+        null=True,
+        blank=True,
+        height_field='height',
+        width_field='width',
+        upload_to=texture_path_handler
+    )
 
-    cloak_height = models.PositiveIntegerField(null=True)
-    cloak_width = models.PositiveIntegerField(null=True)
-    cloak = models.ImageField(null=True, blank=True, height_field='cloak_height', width_field='cloak_width',
-                              upload_to=partial(texture.path_handler, texture.TextureType.CLOAK),
-                              storage=texture.OverwriteStorage())
-
-    elytra_height = models.PositiveIntegerField(null=True)
-    elytra_width = models.PositiveIntegerField(null=True)
-    elytra = models.ImageField(null=True, blank=True, height_field='elytra_height', width_field='elytra_width',
-                               upload_to=partial(texture.path_handler, texture.TextureType.ELYTRA),
-                               storage=texture.OverwriteStorage())
+    class Meta:
+        indexes = [
+            models.Index(fields=['kind', 'deleted', '-created']),
+        ]
 
     def __str__(self):
-        return f"{self.__class__.__name__} for {self.player.username}"
+        return f"{self.__class__.__name__} of type {self.kind} for {self.token.player.username}"
 
 
 @receiver(user_logged_in)
