@@ -6,9 +6,9 @@ from django.db.models import Q
 from django.views.decorators.csrf import csrf_exempt
 from lavender.models import Player, Token
 from lavender.views.api.decorator import json_response
-from nidhoggr_core.repository import BaseUserRepo
-from nidhoggr_core.response import StatusResponse, ErrorResponse
-from nidhoggr_core.user import UserRequest, User, PasswordRequest
+from nidhoggr.core.repository import BaseUserRepo
+from nidhoggr.core.response import StatusResponse, ErrorResponse
+from nidhoggr.core.user import UserRequest, User, PasswordRequest
 
 from lavender.decorators import typed, internal
 
